==> knative-model-4.6.2-sources.jar: annotations/io/fabric8/knative/serving/v1alpha1/ServiceListFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceListFluent<A extends io.fabric8.knative.serving.v1alpha1.ServiceListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,io.fabric8.knative.serving.v1alpha1.Service item);
    public A setToItems(int index,io.fabric8.knative.serving.v1alpha1.Service item);
    public A addToItems(io.fabric8.knative.serving.v1alpha1.Service... items);
    public A addAllToItems(Collection<io.fabric8.knative.serving.v1alpha1.Service> items);
    public A removeFromItems(io.fabric8.knative.serving.v1alpha1.Service... items);
    public A removeAllFromItems(Collection<io.fabric8.knative.serving.v1alpha1.Service> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.serving.v1alpha1.Service> getItems();
    public List<io.fabric8.knative.serving.v1alpha1.Service> buildItems();
    public io.fabric8.knative.serving.v1alpha1.Service buildItem(int index);
    public io.fabric8.knative.serving.v1alpha1.Service buildFirstItem();
    public io.fabric8.knative.serving.v1alpha1.Service buildLastItem();
    public io.fabric8.knative.serving.v1alpha1.Service buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.ServiceBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.ServiceBuilder> predicate);
    public A withItems(List<io.fabric8.knative.serving.v1alpha1.Service> items);
    public A withItems(io.fabric8.knative.serving.v1alpha1.Service... items);
    public Boolean hasItems();
    public ServiceListFluent.ItemsNested<A> addNewItem();
    public ServiceListFluent.ItemsNested<A> addNewItemLike(io.fabric8.knative.serving.v1alpha1.Service item);
    public ServiceListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.knative.serving.v1alpha1.Service item);
    public ServiceListFluent.ItemsNested<A> editItem(int index);
    public ServiceListFluent.ItemsNested<A> editFirstItem();
    public ServiceListFluent.ItemsNested<A> editLastItem();
    public ServiceListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.ServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ServiceFluent<ServiceListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> knative-model-4.7.0-sources.jar: annotations/io/fabric8/knative/serving/v1alpha1/ServiceListFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceListFluent<A extends io.fabric8.knative.serving.v1alpha1.ServiceListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,io.fabric8.knative.serving.v1alpha1.Service item);
    public A setToItems(int index,io.fabric8.knative.serving.v1alpha1.Service item);
    public A addToItems(io.fabric8.knative.serving.v1alpha1.Service... items);
    public A addAllToItems(Collection<io.fabric8.knative.serving.v1alpha1.Service> items);
    public A removeFromItems(io.fabric8.knative.serving.v1alpha1.Service... items);
    public A removeAllFromItems(Collection<io.fabric8.knative.serving.v1alpha1.Service> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.ServiceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.serving.v1alpha1.Service> getItems();
    public List<io.fabric8.knative.serving.v1alpha1.Service> buildItems();
    public io.fabric8.knative.serving.v1alpha1.Service buildItem(int index);
    public io.fabric8.knative.serving.v1alpha1.Service buildFirstItem();
    public io.fabric8.knative.serving.v1alpha1.Service buildLastItem();
    public io.fabric8.knative.serving.v1alpha1.Service buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.ServiceBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.ServiceBuilder> predicate);
    public A withItems(List<io.fabric8.knative.serving.v1alpha1.Service> items);
    public A withItems(io.fabric8.knative.serving.v1alpha1.Service... items);
    public Boolean hasItems();
    public ServiceListFluent.ItemsNested<A> addNewItem();
    public ServiceListFluent.ItemsNested<A> addNewItemLike(io.fabric8.knative.serving.v1alpha1.Service item);
    public ServiceListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.knative.serving.v1alpha1.Service item);
    public ServiceListFluent.ItemsNested<A> editItem(int index);
    public ServiceListFluent.ItemsNested<A> editFirstItem();
    public ServiceListFluent.ItemsNested<A> editLastItem();
    public ServiceListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.ServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ServiceFluent<ServiceListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
